@@ -3,6 +3,28 @@ from autoarray.structures import frames as f
 from autoarray.structures import region as reg
 
 
+def roe_corner_from(ccd_id, quadrant_id):
+
+    row_index = ccd_id[-1]
+
+    if (row_index in "123") and (quadrant_id == "E"):
+        return (1, 0)
+    elif (row_index in "123") and (quadrant_id == "F"):
+        return (1, 1)
+    elif (row_index in "123") and (quadrant_id == "G"):
+        return (0, 1)
+    elif (row_index in "123") and (quadrant_id == "H"):
+        return (0, 0)
+    elif (row_index in "456") and (quadrant_id == "E"):
+        return (0, 1)
+    elif (row_index in "456") and (quadrant_id == "F"):
+        return (0, 0)
+    elif (row_index in "456") and (quadrant_id == "G"):
+        return (1, 0)
+    elif (row_index in "456") and (quadrant_id == "H"):
+        return (1, 1)
+
+
 class FrameEuclid(f.Frame):
     """
     In the Euclid FPA, the quadrant id ('E', 'F', 'G', 'H') depends on whether the CCD is located
@@ -93,9 +115,9 @@ class FrameEuclid(f.Frame):
         ccd_id,
         quadrant_id,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
         """
@@ -186,9 +208,9 @@ class FrameEuclid(f.Frame):
         cls,
         array_electrons,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
         """
@@ -216,10 +238,10 @@ class FrameEuclid(f.Frame):
         cls,
         array,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         parallel_overscan_size=20,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
     ):
         """
         Use an input array of a Euclid quadrant corresponding the top-left of a Euclid CCD and rotate the  quadrant to
@@ -244,9 +266,9 @@ class FrameEuclid(f.Frame):
         cls,
         array,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
         """
@@ -272,9 +294,9 @@ class FrameEuclid(f.Frame):
         cls,
         array,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
         """
@@ -301,9 +323,9 @@ class ScansEuclid(abstract_frame.Scans):
     def top_left(
         cls,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
 
@@ -342,9 +364,9 @@ class ScansEuclid(abstract_frame.Scans):
     def top_right(
         cls,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
 
@@ -380,9 +402,9 @@ class ScansEuclid(abstract_frame.Scans):
     def bottom_left(
         cls,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
 
@@ -421,9 +443,9 @@ class ScansEuclid(abstract_frame.Scans):
     def bottom_right(
         cls,
         parallel_size=2086,
-        serial_size=2119,
+        serial_size=2128,
         serial_prescan_size=51,
-        serial_overscan_size=20,
+        serial_overscan_size=29,
         parallel_overscan_size=20,
     ):
 
