@@ -17,11 +17,11 @@ def subplot_imaging(
         The imaging data_type, which includes the observed data_type, noise_map, PSF, signal-to-noise_map, etc.
     include_origin : True
         If true, the include_origin of the dataset's coordinate system is plotted as a 'x'.
-    image_plane_pix_grid : ndarray or data_type.array.grid_stacks.PixGrid
+    image_plane_pix_grid : np.ndarray or data_type.array.grid_stacks.PixGrid
         If an adaptive pixelization whose pixels are formed by tracing pixels from the dataset, this plots those pixels \
         over the immage.
     ignore_config : bool
-        If *False*, the config file general.ini is used to determine whether the subpot is plotted. If *True*, the \
+        If `False`, the config file general.ini is used to determine whether the subpot is plotted. If `True`, the \
         config file is ignored.
     """
 
@@ -172,7 +172,7 @@ def image(imaging, grid=None, mask=None, positions=None, include=None, plotter=N
         The imaging data_type, which includes the observed data_type, noise_map, PSF, signal-to-noise_map, etc.
     include_origin : True
         If true, the include_origin of the dataset's coordinate system is plotted as a 'x'.
-    image_plane_pix_grid : ndarray or data_type.array.grid_stacks.PixGrid
+    image_plane_pix_grid : np.ndarray or data_type.array.grid_stacks.PixGrid
         If an adaptive pixelization whose pixels are formed by tracing pixels from the dataset, this plots those pixels \
         over the immage.
     """
