@@ -48,7 +48,7 @@ class Kernel(arrays.Array):
         kernel=[1.0, 2.0, 3.0, 4.0]
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked *Mask2D* of shape_2d.
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
 
         Parameters
         ----------
@@ -84,7 +84,7 @@ class Kernel(arrays.Array):
               [3.0, 4.0]]
 
         The 2D shape of the array and its mask are determined from the input array and the mask is setup as an
-        unmasked *Mask2D* of shape_2d.
+        unmasked `Mask2D` of shape_2d.
 
         Parameters
         ----------
@@ -161,7 +161,7 @@ class Kernel(arrays.Array):
          the method numpy ndarray.full.
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked *Mask2D* of shape_2d.
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
 
         Parameters
         ----------
@@ -195,7 +195,7 @@ class Kernel(arrays.Array):
         ndarray.ones.
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked *Mask2D* of shape_2d.
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
 
         Parameters
         ----------
@@ -225,7 +225,7 @@ class Kernel(arrays.Array):
         ndarray.ones.
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked *Mask2D* of shape_2d.
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
 
         Parameters
         ----------
