@@ -434,8 +434,10 @@ def test__exposure_time_map_from_exposure_time_and_inverse_noise_map():
     )
     background_noise_map[0] = 0.5
 
-    exposure_time_map = aa.preprocess.exposure_time_map_from_exposure_time_and_background_noise_map(
-        exposure_time=exposure_time, background_noise_map=background_noise_map
+    exposure_time_map = (
+        aa.preprocess.exposure_time_map_from_exposure_time_and_background_noise_map(
+            exposure_time=exposure_time, background_noise_map=background_noise_map
+        )
     )
 
     assert (
