@@ -1,7 +1,6 @@
 from autoconf import conf
 import autoarray.plot as aplt
 import pytest
-import os
 
 from os import path
 
@@ -10,15 +9,18 @@ directory = path.dirname(path.realpath(__file__))
 
 @pytest.fixture(name="plot_path")
 def make_plot_path_setup():
-    return "{}/files/plots/fit_interferometer/".format(
-        os.path.dirname(os.path.realpath(__file__))
+    return path.join(
+        "{}".format(path.dirname(path.realpath(__file__))),
+        "files",
+        "plots",
+        "fit_interferometer",
     )
 
 
 @pytest.fixture(autouse=True)
 def set_config_path():
     conf.instance = conf.Config(
-        path.join(directory, "files/plotter"), path.join(directory, "output")
+        path.join(directory, "files", "plotter"), path.join(directory, "output")
     )
 
 
@@ -29,35 +31,38 @@ def test__fit_quantities_are_output(fit_interferometer_7, plot_path, plot_patch)
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/visibilities.png" in plot_patch.paths
+    assert path.join(plot_path, "visibilities.png") in plot_patch.paths
 
     aplt.FitInterferometer.noise_map(
         fit=fit_interferometer_7,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/noise_map.png" in plot_patch.paths
+    assert path.join(plot_path, "noise_map.png") in plot_patch.paths
 
     aplt.FitInterferometer.signal_to_noise_map(
         fit=fit_interferometer_7,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/signal_to_noise_map.png" in plot_patch.paths
+    assert path.join(plot_path, "signal_to_noise_map.png") in plot_patch.paths
 
     aplt.FitInterferometer.model_visibilities(
         fit=fit_interferometer_7,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/model_visibilities.png" in plot_patch.paths
+    assert path.join(plot_path, "model_visibilities.png") in plot_patch.paths
 
     aplt.FitInterferometer.residual_map_vs_uv_distances(
         fit=fit_interferometer_7,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/residual_map_vs_uv_distances_real.png" in plot_patch.paths
+    assert (
+        path.join(plot_path, "residual_map_vs_uv_distances_real.png")
+        in plot_patch.paths
+    )
 
     aplt.FitInterferometer.residual_map_vs_uv_distances(
         fit=fit_interferometer_7,
@@ -65,7 +70,10 @@ def test__fit_quantities_are_output(fit_interferometer_7, plot_path, plot_patch)
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/residual_map_vs_uv_distances_imag.png" in plot_patch.paths
+    assert (
+        path.join(plot_path, "residual_map_vs_uv_distances_imag.png")
+        in plot_patch.paths
+    )
 
     aplt.FitInterferometer.normalized_residual_map_vs_uv_distances(
         fit=fit_interferometer_7,
@@ -73,7 +81,7 @@ def test__fit_quantities_are_output(fit_interferometer_7, plot_path, plot_patch)
     )
 
     assert (
-        f"{plot_path}/normalized_residual_map_vs_uv_distances_real.png"
+        path.join(plot_path, "normalized_residual_map_vs_uv_distances_real.png")
         in plot_patch.paths
     )
 
@@ -84,7 +92,7 @@ def test__fit_quantities_are_output(fit_interferometer_7, plot_path, plot_patch)
     )
 
     assert (
-        f"{plot_path}/normalized_residual_map_vs_uv_distances_imag.png"
+        path.join(plot_path, "normalized_residual_map_vs_uv_distances_imag.png")
         in plot_patch.paths
     )
 
@@ -93,7 +101,10 @@ def test__fit_quantities_are_output(fit_interferometer_7, plot_path, plot_patch)
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/chi_squared_map_vs_uv_distances_real.png" in plot_patch.paths
+    assert (
+        path.join(plot_path, "chi_squared_map_vs_uv_distances_real.png")
+        in plot_patch.paths
+    )
 
     aplt.FitInterferometer.chi_squared_map_vs_uv_distances(
         fit=fit_interferometer_7,
@@ -101,7 +112,10 @@ def test__fit_quantities_are_output(fit_interferometer_7, plot_path, plot_patch)
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert f"{plot_path}/chi_squared_map_vs_uv_distances_imag.png" in plot_patch.paths
+    assert (
+        path.join(plot_path, "chi_squared_map_vs_uv_distances_imag.png")
+        in plot_patch.paths
+    )
 
 
 def test__fit_sub_plot(fit_interferometer_7, plot_path, plot_patch):
@@ -111,7 +125,9 @@ def test__fit_sub_plot(fit_interferometer_7, plot_path, plot_patch):
         sub_plotter=aplt.SubPlotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/subplot_fit_interferometer_real.png" in plot_patch.paths
+    assert (
+        path.join(plot_path, "subplot_fit_interferometer_real.png") in plot_patch.paths
+    )
 
 
 def test__fit_individuals__dependent_on_input(
@@ -128,28 +144,40 @@ def test__fit_individuals__dependent_on_input(
         plotter=aplt.Plotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/visibilities.png" in plot_patch.paths
+    assert path.join(plot_path, "visibilities.png") in plot_patch.paths
 
-    assert f"{plot_path}/noise_map.png" not in plot_patch.paths
+    assert path.join(plot_path, "noise_map.png") not in plot_patch.paths
 
-    assert f"{plot_path}/signal_to_noise_map.png" not in plot_patch.paths
+    assert path.join(plot_path, "signal_to_noise_map.png") not in plot_patch.paths
 
-    assert f"{plot_path}/model_visibilities.png" in plot_patch.paths
-
-    assert f"{plot_path}/residual_map_vs_uv_distances_real.png" not in plot_patch.paths
-
-    assert f"{plot_path}/residual_map_vs_uv_distances_imag.png" not in plot_patch.paths
+    assert path.join(plot_path, "model_visibilities.png") in plot_patch.paths
 
     assert (
-        f"{plot_path}/normalized_residual_map_vs_uv_distances_real.png"
+        path.join(plot_path, "residual_map_vs_uv_distances_real.png")
         not in plot_patch.paths
     )
 
     assert (
-        f"{plot_path}/normalized_residual_map_vs_uv_distances_imag.png"
+        path.join(plot_path, "residual_map_vs_uv_distances_imag.png")
         not in plot_patch.paths
     )
 
-    assert f"{plot_path}/chi_squared_map_vs_uv_distances_real.png" in plot_patch.paths
+    assert (
+        path.join(plot_path, "normalized_residual_map_vs_uv_distances_real.png")
+        not in plot_patch.paths
+    )
 
-    assert f"{plot_path}/chi_squared_map_vs_uv_distances_imag.png" in plot_patch.paths
+    assert (
+        path.join(plot_path, "normalized_residual_map_vs_uv_distances_imag.png")
+        not in plot_patch.paths
+    )
+
+    assert (
+        path.join(plot_path, "chi_squared_map_vs_uv_distances_real.png")
+        in plot_patch.paths
+    )
+
+    assert (
+        path.join(plot_path, "chi_squared_map_vs_uv_distances_imag.png")
+        in plot_patch.paths
+    )
